@@ -3,6 +3,7 @@ import sys
 from searcHPV.general import *
 import re
 import string
+import re
 
 ##################
 #find the end of each cigar string slot
@@ -154,8 +155,8 @@ def define_fusion(bam,virus_chrm,out_dir):
                 if read.next_reference_name == virus_chrm:
                     paired_evidence_count += 1
         b[i] += (str(paired_evidence_count),)
-    invalidCharacter = str(string.punctuation)
-    virus_chrm_file_name = virus_chrm.replace(invalidCharacter,"_")
+    invalidCharacter = re.escape(string.punctuation)
+    virus_chrm_file_name = re.sub(r'['+invalidCharacter+']',"_",virus_chrm)
     with open(f'{out_dir}/{virus_chrm_file_name}.genome_fusion.txt','w') as output:
         output.write('chrm\tpos\tsingle_evidence\tpaired_evidence\n')
         for i in b:
